shipkey = "km"
#shipname = "Kilo Moana"

#####################################
# Additional ship configuration information: (all as comments)
#
# deeper blanking interval      use defaults
# IP number                     192.168.2.21
# ntp server                    server 192.168.3.17
#                               server 192.168.3.18
#
# last changed May 20, 2008
###################################



# for DAS_while_cruise.py
#-------------------------
# List of paths to backup "data" subdirectories.  Within each such
# subdirectory, the cruise data directory (e.g., km0507) will
# be found.  If the active cruise is "km0507", then rsync will
# be called periodically to copy the contents of /home/data/km0507
# to data/km0507 in each path in the list.

#backup_paths = ['/disk2/home', '/net/snapserv/adcp']
backup_paths = ['/disk2/home', '/media/UHDAS']


# Interval in seconds between backups

rsync_t = 3600


# for DAS_while_logging.py
#--------------------------

# Interval in seconds between ensemble updates:

short_t = 300

# Interval in seconds between database updates:

long_t = 1800


# Working directory for calculations and intermediate products:

workdir = '/home/adcp/uhdas_tmp'

# Command string to start up the speedlog; empty string or
# None to disable the speedlog.  If there is a speedlog command,
# the string must end with '&' so that it will be executed in
# the background.

#speedlog_cmd = '/home/adcp/scripts/DAS_KMspeedlog.py &'  # backgrounded
speedlog_cmd = None # No speedlog at present.


# for processing
#----------------
# (1) values substituted into cruise_cfg.m (for matlab)

### choose the instrument to use for heading correction.  options:
#  'gyro', 'ashtech', 'posmv', or 'seapath'
## This will be substituted into cruise_cfg.m, where matlab looks for it
hcorr_inst = 'posmv'  ## 'gyro', 'seapath', 'ashtech', ''
acc_heading_cutoff = .018   #default is .065; .015 should be OK for KM

pos_inst = 'posmv'
pos_msg  = 'gps'

hdg_inst = 'gyro'
hdg_msg =  'hdg'

pitch_inst = 'posmv'
pitch_msg = 'pmv'

roll_inst = 'posmv'
roll_msg = 'pmv'


# (2) values substituted into cruise_proc.m  (for matlab)

# heading alignment:  nominal - (cal/watertrack)
h_align = {}
h_align['os38']  = 44.55
h_align['wh300']  = 45.52

# transducer depth, meters
ducer_depth = {}
ducer_depth['os38']   = 7
ducer_depth['wh300']  = 7

# optional: weakprof_numbins
# weakprof_numbins = {'os38bb' : 2}

# velocity scalefactor
scalefactor = {}
scalefactor['os38bb']  = 1.0     ## this should be the default
scalefactor['os38nb']  = 1.0     # then it could mostly be left out
scalefactor['wh300'] = 1.0

# soundspeed
soundspeed = {}
soundspeed['os38bb'] = None      # NOTE: use 'calculate' for NB150
soundspeed['os38nb'] = None      #    if instrument was configured that way.
soundspeed['wh300bb'] = None

# salinity
salinity = {}
salinity['os38bb'] = None       ## NOTE: use fixed value such as 34.5 or 35.0
salinity['os38nb'] = None       ## for NB150 if using 'calculate' for soundspeed
salinity['wh300'] = None

# (3) values for quick_adcp.py

## choose whether or not to use topography for editing
## uses smith,sandwell version from about 2004
use_topo4edit = 1

# averaging interval (seconds) usually 300.  might use 120sec for wh300
enslength = {}
enslength['os38bb']  = 300
enslength['os38nb']  = 300
enslength['wh300'] = 120

# (4) values for web plots and quality monitoring

## daily.py will get statistics on these (assumes correct messages are logged)
## and quality plots will go on the web site on the long_t timer
attitude_devices = ['posmv',] # 'ashtech']    # string or list of strings

# new section, to create cruise_proc.m
# all dictionaries must be filled

## for quick_adcp.py: # initialize; # fill
## going to be top_plotbin
top_plotbin = {}
top_plotbin['os38bb'] = 1
top_plotbin['os38nb'] = 1         ## set deeper, eg 2, if instrument has ringing
top_plotbin['wh300'] = 1

## which virtual instrument will be used for kts+dir 5-minute bridge plots?
## going to be kt_dir_instlist ['os38nb', 'os38bb']
kts_dir_instrument = ['wh300', 'os38bb', 'os38nb']

#####################################

# for daily.py:
#--------------

# Each email "mailto" must be a list of email addresses:
#        ["et@this_ship.podunk.edu", "guru@podunk.edu"]
# An empty list (no addresses) is : []


tarball_mailto  = ["uhdas@soest.hawaii.edu"]

# includes web links on currents:
local_status_mailto   = ["sisprog@km.soest.hawaii.edu",]

shore_status_mailto  = ["hummon@hawaii.edu", "efiring@hawaii.edu"]

SMTP_server     = "mail.km.soest.hawaii.edu"
mail_from       = "adcp@km.soest.hawaii.edu"


#####################################


