# This configuration file is Python code.  You should not
# need to change it; but if you do, you need to know that
# in Python, the *indentation matters*.

# The following will normally be empty lists, like this:
#
#ignore_ADCPs = []
#ignore_other_sensors = []
#
# But if you want to run with only a subset of the ADCPs
# and/or ancillary sensors that are defined in this file,
# you can list the ones you want to ignore like this:
#
#ignore_ADCPs = ['wh300', 'os75']
#ignore_other_sensors = ['GPS']
#
# In this case, you are listing the 'instrument' field of each
# ADCP or sensor you wish to exclude.
#

ignore_ADCPs = []
ignore_other_sensors = []

# 2-letter abbreviation for logging file prefix and constructing dbase name;
# read by procsetup.py
shipabbrev = "km"

ADCPs = [
        { 'instrument'  :  'wh300',
          'setup'       :  'rdi_setup',
          'terminal'    :  'oswh_term',
          'defaultcmd'  :  'wh300_default.cmd',
          'commands'    :  ('EA04500',),   # Add WM*, WV* here to override default.
          'datatypes'   :  ('wh300',),
          'wakeup_baud' :  9600
        },
        { 'instrument'  :  'os38',
          'setup'       :  'rdi_setup',
          'terminal'    :  'oswh_term',
          'defaultcmd'  :  'os38_default.cmd',
          'commands'    :  ('EA04500',),
          'datatypes'   :  ('os38bb', 'os38nb'),
          'wakeup_baud' :  9600
        }


        ]


# Do not edit the next three lines:
common_opts = '-f %s -F -m 1 -H 2 ' % (shipabbrev,)
nb_opts =   '-rlE -c -I'          # raw data, write a log file, log errors
oswh_opts = '-rlE -c -O -I'       # -O for OS/WH data format
                                  # -c for checksum, -I to initiate pinging

sensors = [

        { 'instrument'  :  'wh300',
          'device'      :  'ttyR7',  #tty_dgnc_0_7' for digi
          'baud'        :   38400,      # Some errors at 115200
          'format'      :  'binary',
          'subdir'      :  'wh300',
          'ext'         :  'raw',
          'opt'         :  oswh_opts}, # Note -I option for new ser_bin.


        { 'instrument'  :  'os38',       # Passive logging of OS
          'device'      :  'ttyS0',
          'baud'        :   38400,       # Some errors at 115200.
          'format'      :  'binary',
          'subdir'      :  'os38',
          'ext'         :  'raw',
          'opt'         :  oswh_opts}, # Note -I option for new ser_bin.

        { 'instrument'  :  'ADU5',
          'device'      :  'ttyR6',   # tty_dgnc_0_6 for digi
          'baud'        :   9600,
          'format'      :  'ascii',
          'subdir'      :  'ashtech',
          'ext'         :  'adu',
          'strings'     :  ('$PASHR,ATT', '$GPGGA'),
          'messages'    :  ('gps', 'adu'),
          'opt'         :  '-tc'},
#
#  pcode is gone.  taking it out Jan 2010
#
#        { 'instrument'  :  'GPS',
#          'device'      :  'ttyR1',   #tty_dgnc_0_1 for  digi
#          'baud'        :   9600,
#          'format'      :  'ascii',
#          'subdir'      :  'gpsnav',
#          'ext'         :  'gps',
#          'strings'     :  ('$GPGGA',),
#          'messages'    :  ('gps',),
#          'opt'         :  '-tc'},

        { 'instrument'  :  'GPS Sim',
          'device'      :  'ttyR2',   #tty_dgnc_0_2 for digi
          'baud'        :   9600,
          'format'      :  'ascii',
          'subdir'      :  'simrad',
          'ext'         :  'gps',
          'strings'     :  ('$GPGGA',),
          'messages'    :  ('gps',),
          'opt'         :  '-tc'},


        { 'instrument'  :  'POS/MV',
          'device'      :  'ttyR0',   # tty_dgnc_0_0 for digi
          'baud'        :   9600,
          'format'      :  'ascii',
          'subdir'      :  'posmv',
          'ext'         :  'pmv',
          'strings'     :  ('$INGGA', '$PASHR'),
          #'strings'     :  (),
          'messages'    :  ('gps', 'pmv'),
          'opt'         :  '-tc'},
          #'opt'         :  '-ta'},

        { 'instrument'  :  'Gyro',
          'device'      :  'ttyR5',   # tty_dgnc_0_5 for digi
          'baud'        :   4800,
          'format'      :  'ascii',
          'subdir'      :  'gyro',
          'ext'         :  'hdg',
          'strings'     :  ('$HEHDT',),
          'messages'    :  ('hdg',),
          'opt'         :  '-tc'}  ]

## enabling or disabling this occurs in procsetup_onship.py
speedlog_config = {
    'instrument'        : 'wh300',
    'serial_device'     : '/dev/ttyR4',
    'baud'              : 9600,
    'dir_output'        : '',
    'heading_offset'    : 45.0,
    'scale'             : 1.0,
    'bins'              : (1,12),

    'heading_sensor'    : 'posmv',
    'heading_msg'       : 'pmv',

    'soundspeed_sensor' : None,
    'soundspeed_msg'    : 'snd',
    'nominal_soundspeed': 1536.0,
    }




#### DO NOT CHANGE the following ################

ADCPs = [A for A in ADCPs if A['instrument'] not in ignore_ADCPs]
sensors = [S for S in sensors if S['instrument'] not in ignore_ADCPs]
sensors = [S for S in sensors if S['instrument'] not in ignore_other_sensors]



